@@ -33,6 +33,9 @@ class Model:
     def __hash__(self):
         return hash(self.uid)
 
+    def __repr__(self):
+        return self.__str__()
+
 
 class ModelType(Enum):
     ACOUSTIC = 'AM'
